@@ -19,7 +19,7 @@
 #' @param npaths Number of bootstrapped sample paths to use if \code{bootstrap==TRUE}.
 #' @param x Deprecated. Included for backwards compatibility.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -113,7 +113,7 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
 
   out <- list(
     method = "Mean", level = level, x = x, series = deparse(substitute(y)), mean = f, lower = lower, upper = upper,
-    model = list(mu = f[1], mu.se = s / sqrt(length(x)), sd = s, bootstrap = bootstrap), lambda = lambda, fitted = fits, residuals = res
+    model = structure(list(mu = f[1], mu.se = s / sqrt(length(x)), sd = s, bootstrap = bootstrap), class = "meanf"), lambda = lambda, fitted = fits, residuals = res
   )
   out$model$call <- match.call()
 
@@ -121,8 +121,6 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
 }
 
 
-
-
 #' Box Cox Transformation
 #'
 #' BoxCox() returns a transformation of the input variable using a Box-Cox
@@ -134,7 +132,7 @@ meanf <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FALS
 #' \deqn{f_0(x)=\log(x)}{f(x;0)=log(x)}.
 #'
 #' @param x a numeric vector or time series of class \code{ts}.
-#' @param lambda transformation parameter. If \code{lambda = "auto"}, then 
+#' @param lambda transformation parameter. If \code{lambda = "auto"}, then
 #' the transformation parameter lambda is chosen using BoxCox.lambda.
 #' @param biasadj Use adjusted back-transformed mean for Box-Cox
 #' transformations. If transformed data is used to produce forecasts and fitted values,
@@ -214,7 +212,7 @@ InvBoxCox <- function(x, lambda, biasadj=FALSE, fvar=NULL) {
       }
       level <- mean(c(level, 1))
       # Note: Use BoxCox transformed upper and lower values
-      fvar <- ((fvar$upper - fvar$lower) / stats::qnorm(level) / 2) ^ 2
+      fvar <- as.numeric((fvar$upper - fvar$lower) / stats::qnorm(level) / 2) ^ 2
     }
     if (NCOL(fvar) > 1) {
       fvar <- diag(fvar)
@@ -272,7 +270,7 @@ InvBoxCoxf <- function(x=NULL, fvar=NULL, lambda=NULL) {
 #' fan plots.
 #' @param ... Other arguments.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -330,8 +328,11 @@ forecast.StructTS <- function(object, h=ifelse(object$coef["epsilon"] > 1e-10, 2
     method <- "Local level structural model"
   }
 
-  fits <- ts(c(x - residuals(object)))
-  tsp(fits) <- tsp(x)
+  # Compute fitted values and residuals
+  sigma2 <- c(predict(object, n.ahead=1)$se)
+  res <- residuals(object) * sigma2
+  fits <- x - res
+
   if (!is.null(lambda)) {
     fits <- InvBoxCox(fits, lambda)
     x <- InvBoxCox(x, lambda)
@@ -340,11 +341,10 @@ forecast.StructTS <- function(object, h=ifelse(object$coef["epsilon"] > 1e-10, 2
     upper <- InvBoxCox(upper, lambda)
   }
 
-
   return(structure(
     list(
       method = method, model = object, level = level, mean = pred$pred,
-      lower = lower, upper = upper, x = x, series = object$series, fitted = fits, residuals = x-fits
+      lower = lower, upper = upper, x = x, series = object$series, fitted = fits, residuals = res
     ),
     class = "forecast"
   ))
@@ -369,7 +369,7 @@ forecast.StructTS <- function(object, h=ifelse(object$coef["epsilon"] > 1e-10, 2
 #' fan plots.
 #' @param ... Other arguments.
 #' @inheritParams forecast
-#' 
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -462,8 +462,6 @@ forecast.HoltWinters <- function(object, h=ifelse(frequency(object$x) > 1, 2 * f
 
 ## CROSTON
 
-
-
 #' Forecasts for intermittent demand using Croston's method
 #'
 #' Returns forecasts and other information for Croston's forecasts applied to
