@@ -3,7 +3,7 @@ if (require(testthat)) {
   context("Testing graph")
   test_that("Tests for seasonplot()", {
     expect_error(seasonplot(airmiles))
-    seasonplot(ts(gold, f = 7))
+    seasonplot(ts(gold, frequency = 7))
     seasonplot(woolyrnq)
     seasonplot(wineind)
     seasonplot(wineind, year.labels = TRUE)
